var _excluded = ["label", "description", "errorText", "raw", "error", "prefixel", "suffixel", "style", "tooltip", "tooltipConfig", "value", "defaultValue", "valueFormatOptions", "onChange"];
function _extends() { return _extends = Object.assign ? Object.assign.bind() : function (n) { for (var e = 1; e < arguments.length; e++) { var t = arguments[e]; for (var r in t) ({}).hasOwnProperty.call(t, r) && (n[r] = t[r]); } return n; }, _extends.apply(null, arguments); }
function _objectWithoutPropertiesLoose(r, e) { if (null == r) return {}; var t = {}; for (var n in r) if ({}.hasOwnProperty.call(r, n)) { if (-1 !== e.indexOf(n)) continue; t[n] = r[n]; } return t; }
import React, { useCallback, useEffect, useMemo, useRef, useState } from 'react';
import { v4 as uuid } from 'uuid';
import '@synerise/ds-core/dist/js/style';
import { useDataFormat } from '@synerise/ds-data-format';
import FormField from '@synerise/ds-form-field';
import * as S from './InputNumber.styles';
import "./style/index.css";
import { formatNumber, parseFormattedNumber } from './utils/inputNumber.utils';
var InputNumber = function InputNumber(_ref) {
  var label = _ref.label,
    description = _ref.description,
    errorText = _ref.errorText,
    raw = _ref.raw,
    error = _ref.error,
    prefixel = _ref.prefixel,
    suffixel = _ref.suffixel,
    style = _ref.style,
    tooltip = _ref.tooltip,
    tooltipConfig = _ref.tooltipConfig,
    value = _ref.value,
    defaultValue = _ref.defaultValue,
    valueFormatOptions = _ref.valueFormatOptions,
    onChange = _ref.onChange,
    antdProps = _objectWithoutPropertiesLoose(_ref, _excluded);
  var _useDataFormat = useDataFormat(),
    formatValue = _useDataFormat.formatValue,
    thousandDelimiter = _useDataFormat.thousandDelimiter,
    decimalDelimiter = _useDataFormat.decimalDelimiter;
  var _useState = useState(value != null ? value : defaultValue),
    localValue = _useState[0],
    setLocalValue = _useState[1];
  var antdInputRef = useRef(null);
  useEffect(function () {
    if (value !== undefined && value !== localValue) {
      setLocalValue(value);
    }
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [value]);
  var id = useMemo(function () {
    return uuid();
  }, []);
  var showError = Boolean(error || errorText);
  var formatter = useCallback(function (inputValue) {
    var formatted = formatNumber(inputValue, formatValue, thousandDelimiter, decimalDelimiter, valueFormatOptions);
    return formatted;
  }, [formatValue, valueFormatOptions, thousandDelimiter, decimalDelimiter]);
  var parser = useCallback(function (inputValue) {
    return parseFloat("" + parseFormattedNumber(inputValue, formatValue, thousandDelimiter, decimalDelimiter));
  }, [formatValue, thousandDelimiter, decimalDelimiter]);
  var handleOnChange = useCallback(function (changedValue) {
    var formattedValue = formatter(changedValue);
    var parsedFormattedValue = parser(formattedValue);
    var valueAsNumber = typeof parsedFormattedValue === 'string' ? parseFloat(parsedFormattedValue) : parsedFormattedValue;
    var resultValue = Number.isNaN(valueAsNumber) ? defaultValue : valueAsNumber;
    setLocalValue(resultValue);
    onChange && onChange(resultValue != null ? resultValue : null);
  }, [formatter, parser, defaultValue, onChange]);
  useEffect(function () {
    var input = antdInputRef.current;
    var cancelNonNumeric = function cancelNonNumeric(event) {
      if (!/^-?\d*(\.|,)?\d*$/i.test(event.key)) {
        event.preventDefault();
      }
    };
    if (input) {
      input.addEventListener('keypress', cancelNonNumeric);
    }
    return function () {
      if (input) {
        input.removeEventListener('keypress', cancelNonNumeric);
      }
    };
  });
  var rawInput = /*#__PURE__*/React.createElement(S.InputNumberWrapper, {
    prefixel: !!prefixel,
    suffixel: !!suffixel,
    style: style
  }, !!prefixel && /*#__PURE__*/React.createElement(S.Prefixel, null, prefixel), /*#__PURE__*/React.createElement(S.AntdInputNumber, _extends({}, antdProps, {
    ref: antdInputRef,
    onChange: handleOnChange,
    id: id,
    error: showError,
    className: showError ? 'error' : undefined,
    autoComplete: "off",
    formatter: formatter,
    parser: parser,
    defaultValue: defaultValue,
    value: localValue,
    decimalSeparator: decimalDelimiter
  })), !!suffixel && /*#__PURE__*/React.createElement(S.Suffixel, null, suffixel));
  if (raw) {
    return /*#__PURE__*/React.createElement(S.InputNumberContainer, null, rawInput);
  }
  return /*#__PURE__*/React.createElement(S.InputNumberContainer, null, /*#__PURE__*/React.createElement(FormField, {
    id: id,
    label: label,
    tooltip: tooltip,
    tooltipConfig: tooltipConfig,
    description: description,
    errorText: errorText
  }, rawInput));
};
export default InputNumber;